---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior. Typically a minimized snippet of input code that can be fed to the compiler to produce the bug you're seeing. If you provide a code snippet, please do so as actual text instead of a screenshot, as it's much easier to copy the text and reproduce the problem locally than it is to transcribe it from an image first.

**Additional context**
Add any other context about the problem here. If you have a non-standard setup or anything unusual that may be contributing to the problem it's good to include that here.
